# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily_analytics/v1/daily_volatility.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDsystemathics/apis/services/daily_analytics/v1/daily_volatility.proto\x12-systemathics.apis.services.daily_analytics.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xb2\x01\n\x16\x44\x61ilyVolatilityRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x03 \x01(\x08\"(\n\x17\x44\x61ilyVolatilityResponse\x12\r\n\x05value\x18\x01 \x01(\x01\x32\xbb\x01\n\x16\x44\x61ilyVolatilityService\x12\xa0\x01\n\x0f\x44\x61ilyVolatility\x12\x45.systemathics.apis.services.daily_analytics.v1.DailyVolatilityRequest\x1a\x46.systemathics.apis.services.daily_analytics.v1.DailyVolatilityResponseb\x06proto3')



_DAILYVOLATILITYREQUEST = DESCRIPTOR.message_types_by_name['DailyVolatilityRequest']
_DAILYVOLATILITYRESPONSE = DESCRIPTOR.message_types_by_name['DailyVolatilityResponse']
DailyVolatilityRequest = _reflection.GeneratedProtocolMessageType('DailyVolatilityRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYVOLATILITYREQUEST,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_volatility_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyVolatilityRequest)
  })
_sym_db.RegisterMessage(DailyVolatilityRequest)

DailyVolatilityResponse = _reflection.GeneratedProtocolMessageType('DailyVolatilityResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYVOLATILITYRESPONSE,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_volatility_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyVolatilityResponse)
  })
_sym_db.RegisterMessage(DailyVolatilityResponse)

_DAILYVOLATILITYSERVICE = DESCRIPTOR.services_by_name['DailyVolatilityService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DAILYVOLATILITYREQUEST._serialized_start=223
  _DAILYVOLATILITYREQUEST._serialized_end=401
  _DAILYVOLATILITYRESPONSE._serialized_start=403
  _DAILYVOLATILITYRESPONSE._serialized_end=443
  _DAILYVOLATILITYSERVICE._serialized_start=446
  _DAILYVOLATILITYSERVICE._serialized_end=633
# @@protoc_insertion_point(module_scope)
