# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/corporate_actions/v1/splits.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<systemathics/apis/services/corporate_actions/v1/splits.proto\x12/systemathics.apis.services.corporate_actions.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\x95\x01\n\rSplitsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\"V\n\x0eSplitsResponse\x12\x44\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.corporate_actions.v1.Split\"_\n\x05Split\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\x12\n\nnew_shares\x18\x02 \x01(\x01\x12\x12\n\nold_shares\x18\x03 \x01(\x01\x12\r\n\x05score\x18\x04 \x01(\x01\x32\x9b\x01\n\rSplitsService\x12\x89\x01\n\x06Splits\x12>.systemathics.apis.services.corporate_actions.v1.SplitsRequest\x1a?.systemathics.apis.services.corporate_actions.v1.SplitsResponseb\x06proto3')



_SPLITSREQUEST = DESCRIPTOR.message_types_by_name['SplitsRequest']
_SPLITSRESPONSE = DESCRIPTOR.message_types_by_name['SplitsResponse']
_SPLIT = DESCRIPTOR.message_types_by_name['Split']
SplitsRequest = _reflection.GeneratedProtocolMessageType('SplitsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SPLITSREQUEST,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.splits_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.SplitsRequest)
  })
_sym_db.RegisterMessage(SplitsRequest)

SplitsResponse = _reflection.GeneratedProtocolMessageType('SplitsResponse', (_message.Message,), {
  'DESCRIPTOR' : _SPLITSRESPONSE,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.splits_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.SplitsResponse)
  })
_sym_db.RegisterMessage(SplitsResponse)

Split = _reflection.GeneratedProtocolMessageType('Split', (_message.Message,), {
  'DESCRIPTOR' : _SPLIT,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.splits_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.Split)
  })
_sym_db.RegisterMessage(Split)

_SPLITSSERVICE = DESCRIPTOR.services_by_name['SplitsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SPLITSREQUEST._serialized_start=241
  _SPLITSREQUEST._serialized_end=390
  _SPLITSRESPONSE._serialized_start=392
  _SPLITSRESPONSE._serialized_end=478
  _SPLIT._serialized_start=480
  _SPLIT._serialized_end=575
  _SPLITSSERVICE._serialized_start=578
  _SPLITSSERVICE._serialized_end=733
# @@protoc_insertion_point(module_scope)
