# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday_analytics/v1/intraday_volatility.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJsystemathics/apis/services/intraday_analytics/v1/intraday_volatility.proto\x12\x30systemathics.apis.services.intraday_analytics.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xf3\x01\n\x19IntradayVolatilityRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x04 \x01(\x08\"+\n\x1aIntradayVolatilityResponse\x12\r\n\x05value\x18\x01 \x01(\x01\x32\xcd\x01\n\x19IntradayVolatilityService\x12\xaf\x01\n\x12IntradayVolatility\x12K.systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityRequest\x1aL.systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityResponseb\x06proto3')



_INTRADAYVOLATILITYREQUEST = DESCRIPTOR.message_types_by_name['IntradayVolatilityRequest']
_INTRADAYVOLATILITYRESPONSE = DESCRIPTOR.message_types_by_name['IntradayVolatilityResponse']
IntradayVolatilityRequest = _reflection.GeneratedProtocolMessageType('IntradayVolatilityRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYVOLATILITYREQUEST,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_volatility_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityRequest)
  })
_sym_db.RegisterMessage(IntradayVolatilityRequest)

IntradayVolatilityResponse = _reflection.GeneratedProtocolMessageType('IntradayVolatilityResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYVOLATILITYRESPONSE,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_volatility_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityResponse)
  })
_sym_db.RegisterMessage(IntradayVolatilityResponse)

_INTRADAYVOLATILITYSERVICE = DESCRIPTOR.services_by_name['IntradayVolatilityService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INTRADAYVOLATILITYREQUEST._serialized_start=281
  _INTRADAYVOLATILITYREQUEST._serialized_end=524
  _INTRADAYVOLATILITYRESPONSE._serialized_start=526
  _INTRADAYVOLATILITYRESPONSE._serialized_end=569
  _INTRADAYVOLATILITYSERVICE._serialized_start=572
  _INTRADAYVOLATILITYSERVICE._serialized_end=777
# @@protoc_insertion_point(module_scope)
