# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/keys.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+systemathics/apis/type/shared/v1/keys.proto\x12 systemathics.apis.type.shared.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"V\n\x03Key\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\r\n\x05value\x18\x02 \x01(\r\"=\n\x04Keys\x12\x35\n\x06values\x18\x01 \x03(\x0b\x32%.systemathics.apis.type.shared.v1.Keyb\x06proto3')



_KEY = DESCRIPTOR.message_types_by_name['Key']
_KEYS = DESCRIPTOR.message_types_by_name['Keys']
Key = _reflection.GeneratedProtocolMessageType('Key', (_message.Message,), {
  'DESCRIPTOR' : _KEY,
  '__module__' : 'systemathics.apis.type.shared.v1.keys_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Key)
  })
_sym_db.RegisterMessage(Key)

Keys = _reflection.GeneratedProtocolMessageType('Keys', (_message.Message,), {
  'DESCRIPTOR' : _KEYS,
  '__module__' : 'systemathics.apis.type.shared.v1.keys_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Keys)
  })
_sym_db.RegisterMessage(Keys)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _KEY._serialized_start=132
  _KEY._serialized_end=218
  _KEYS._serialized_start=220
  _KEYS._serialized_end=281
# @@protoc_insertion_point(module_scope)
