# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily/v1/daily_prices.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6systemathics/apis/services/daily/v1/daily_prices.proto\x12#systemathics.apis.services.daily.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xae\x01\n\x12\x44\x61ilyPricesRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x03 \x01(\x08\"T\n\x13\x44\x61ilyPricesResponse\x12=\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32/.systemathics.apis.services.daily.v1.DailyPrice\"[\n\nDailyPrice\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x0e\n\x06volume\x18\x03 \x01(\x03\x12\r\n\x05score\x18\x04 \x01(\x01\x32\x97\x01\n\x12\x44\x61ilyPricesService\x12\x80\x01\n\x0b\x44\x61ilyPrices\x12\x37.systemathics.apis.services.daily.v1.DailyPricesRequest\x1a\x38.systemathics.apis.services.daily.v1.DailyPricesResponseb\x06proto3')



_DAILYPRICESREQUEST = DESCRIPTOR.message_types_by_name['DailyPricesRequest']
_DAILYPRICESRESPONSE = DESCRIPTOR.message_types_by_name['DailyPricesResponse']
_DAILYPRICE = DESCRIPTOR.message_types_by_name['DailyPrice']
DailyPricesRequest = _reflection.GeneratedProtocolMessageType('DailyPricesRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYPRICESREQUEST,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_prices_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyPricesRequest)
  })
_sym_db.RegisterMessage(DailyPricesRequest)

DailyPricesResponse = _reflection.GeneratedProtocolMessageType('DailyPricesResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYPRICESRESPONSE,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_prices_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyPricesResponse)
  })
_sym_db.RegisterMessage(DailyPricesResponse)

DailyPrice = _reflection.GeneratedProtocolMessageType('DailyPrice', (_message.Message,), {
  'DESCRIPTOR' : _DAILYPRICE,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_prices_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyPrice)
  })
_sym_db.RegisterMessage(DailyPrice)

_DAILYPRICESSERVICE = DESCRIPTOR.services_by_name['DailyPricesService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DAILYPRICESREQUEST._serialized_start=223
  _DAILYPRICESREQUEST._serialized_end=397
  _DAILYPRICESRESPONSE._serialized_start=399
  _DAILYPRICESRESPONSE._serialized_end=483
  _DAILYPRICE._serialized_start=485
  _DAILYPRICE._serialized_end=576
  _DAILYPRICESSERVICE._serialized_start=579
  _DAILYPRICESSERVICE._serialized_end=730
# @@protoc_insertion_point(module_scope)
