# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/sampling.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/systemathics/apis/type/shared/v1/sampling.proto\x12 systemathics.apis.type.shared.v1*\xc0\x01\n\x08Sampling\x12\x18\n\x14SAMPLING_UNSPECIFIED\x10\x00\x12\x17\n\x13SAMPLING_ONE_MINUTE\x10\x01\x12\x18\n\x14SAMPLING_FIVE_MINUTE\x10\x02\x12\x17\n\x13SAMPLING_TEN_MINUTE\x10\x03\x12\x1b\n\x17SAMPLING_FIFTEEN_MINUTE\x10\x04\x12\x1a\n\x16SAMPLING_THIRTY_MINUTE\x10\x05\x12\x15\n\x11SAMPLING_ONE_HOUR\x10\x06\x62\x06proto3')

_SAMPLING = DESCRIPTOR.enum_types_by_name['Sampling']
Sampling = enum_type_wrapper.EnumTypeWrapper(_SAMPLING)
SAMPLING_UNSPECIFIED = 0
SAMPLING_ONE_MINUTE = 1
SAMPLING_FIVE_MINUTE = 2
SAMPLING_TEN_MINUTE = 3
SAMPLING_FIFTEEN_MINUTE = 4
SAMPLING_THIRTY_MINUTE = 5
SAMPLING_ONE_HOUR = 6


if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SAMPLING._serialized_start=86
  _SAMPLING._serialized_end=278
# @@protoc_insertion_point(module_scope)
