# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday_analytics/v1/intraday_macd.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDsystemathics/apis/services/intraday_analytics/v1/intraday_macd.proto\x12\x30systemathics.apis.services.intraday_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\x8a\x02\n\x13IntradayMacdRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x0c\n\x04long\x18\x04 \x01(\x05\x12\r\n\x05short\x18\x05 \x01(\x05\x12\x12\n\nadjustment\x18\x06 \x01(\x08\"h\n\x14IntradayMacdResponse\x12P\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x42.systemathics.apis.services.intraday_analytics.v1.IntradayMacdData\"|\n\x10IntradayMacdData\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x0c\n\x04macd\x18\x03 \x01(\x01\x12\r\n\x05short\x18\x04 \x01(\x01\x12\x0c\n\x04long\x18\x05 \x01(\x01\x32\xb5\x01\n\x13IntradayMacdService\x12\x9d\x01\n\x0cIntradayMacd\x12\x45.systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest\x1a\x46.systemathics.apis.services.intraday_analytics.v1.IntradayMacdResponseb\x06proto3')



_INTRADAYMACDREQUEST = DESCRIPTOR.message_types_by_name['IntradayMacdRequest']
_INTRADAYMACDRESPONSE = DESCRIPTOR.message_types_by_name['IntradayMacdResponse']
_INTRADAYMACDDATA = DESCRIPTOR.message_types_by_name['IntradayMacdData']
IntradayMacdRequest = _reflection.GeneratedProtocolMessageType('IntradayMacdRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYMACDREQUEST,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_macd_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest)
  })
_sym_db.RegisterMessage(IntradayMacdRequest)

IntradayMacdResponse = _reflection.GeneratedProtocolMessageType('IntradayMacdResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYMACDRESPONSE,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_macd_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayMacdResponse)
  })
_sym_db.RegisterMessage(IntradayMacdResponse)

IntradayMacdData = _reflection.GeneratedProtocolMessageType('IntradayMacdData', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYMACDDATA,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_macd_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayMacdData)
  })
_sym_db.RegisterMessage(IntradayMacdData)

_INTRADAYMACDSERVICE = DESCRIPTOR.services_by_name['IntradayMacdService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INTRADAYMACDREQUEST._serialized_start=308
  _INTRADAYMACDREQUEST._serialized_end=574
  _INTRADAYMACDRESPONSE._serialized_start=576
  _INTRADAYMACDRESPONSE._serialized_end=680
  _INTRADAYMACDDATA._serialized_start=682
  _INTRADAYMACDDATA._serialized_end=806
  _INTRADAYMACDSERVICE._serialized_start=809
  _INTRADAYMACDSERVICE._serialized_end=990
# @@protoc_insertion_point(module_scope)
