# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/constraints.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.type import dayofweek_pb2 as google_dot_type_dot_dayofweek__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2
from systemathics.apis.type.shared.v1 import time_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_time__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2systemathics/apis/type/shared/v1/constraints.proto\x12 systemathics.apis.type.shared.v1\x1a\x16google/type/date.proto\x1a\x1bgoogle/type/dayofweek.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\x1a\x34systemathics/apis/type/shared/v1/time_interval.proto\"\xf7\x01\n\x0b\x43onstraints\x12\x46\n\x0e\x64\x61te_intervals\x18\x01 \x03(\x0b\x32..systemathics.apis.type.shared.v1.DateInterval\x12\x46\n\x0etime_intervals\x18\x02 \x03(\x0b\x32..systemathics.apis.type.shared.v1.TimeInterval\x12)\n\x0e\x65xcluded_dates\x18\x03 \x03(\x0b\x32\x11.google.type.Date\x12-\n\rexcluded_days\x18\x04 \x03(\x0e\x32\x16.google.type.DayOfWeekb\x06proto3')



_CONSTRAINTS = DESCRIPTOR.message_types_by_name['Constraints']
Constraints = _reflection.GeneratedProtocolMessageType('Constraints', (_message.Message,), {
  'DESCRIPTOR' : _CONSTRAINTS,
  '__module__' : 'systemathics.apis.type.shared.v1.constraints_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Constraints)
  })
_sym_db.RegisterMessage(Constraints)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONSTRAINTS._serialized_start=250
  _CONSTRAINTS._serialized_end=497
# @@protoc_insertion_point(module_scope)
