# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/mappings.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import memo_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_memo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/systemathics/apis/type/shared/v1/mappings.proto\x12 systemathics.apis.type.shared.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a+systemathics/apis/type/shared/v1/memo.proto\"\x97\x01\n\x07Mapping\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x34\n\x04memo\x18\x02 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.Memo\x12\x14\n\x0c\x65vent_source\x18\x03 \x01(\r\"D\n\x08Mappings\x12\x38\n\x05table\x18\x01 \x03(\x0b\x32).systemathics.apis.type.shared.v1.Mappingb\x06proto3')



_MAPPING = DESCRIPTOR.message_types_by_name['Mapping']
_MAPPINGS = DESCRIPTOR.message_types_by_name['Mappings']
Mapping = _reflection.GeneratedProtocolMessageType('Mapping', (_message.Message,), {
  'DESCRIPTOR' : _MAPPING,
  '__module__' : 'systemathics.apis.type.shared.v1.mappings_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Mapping)
  })
_sym_db.RegisterMessage(Mapping)

Mappings = _reflection.GeneratedProtocolMessageType('Mappings', (_message.Message,), {
  'DESCRIPTOR' : _MAPPINGS,
  '__module__' : 'systemathics.apis.type.shared.v1.mappings_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Mappings)
  })
_sym_db.RegisterMessage(Mappings)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MAPPING._serialized_start=182
  _MAPPING._serialized_end=333
  _MAPPINGS._serialized_start=335
  _MAPPINGS._serialized_end=403
# @@protoc_insertion_point(module_scope)
