# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/quote.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import side_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_side__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,systemathics/apis/type/shared/v1/quote.proto\x12 systemathics.apis.type.shared.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a+systemathics/apis/type/shared/v1/side.proto\"\xd1\x01\n\x05Quote\x12\n\n\x02id\x18\x01 \x01(\t\x12)\n\x04size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12+\n\x05price\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12.\n\tcondition\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x34\n\x04side\x18\x05 \x01(\x0e\x32&.systemathics.apis.type.shared.v1.Sideb\x06proto3')



_QUOTE = DESCRIPTOR.message_types_by_name['Quote']
Quote = _reflection.GeneratedProtocolMessageType('Quote', (_message.Message,), {
  'DESCRIPTOR' : _QUOTE,
  '__module__' : 'systemathics.apis.type.shared.v1.quote_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Quote)
  })
_sym_db.RegisterMessage(Quote)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _QUOTE._serialized_start=160
  _QUOTE._serialized_end=369
# @@protoc_insertion_point(module_scope)
