# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_trade_condition_statistics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRsystemathics/apis/services/tick_analytics/v1/tick_trade_condition_statistics.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xab\x01\n#TickTradeConditionStatisticsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\"\xa8\x01\n$TickTradeConditionStatisticsResponse\x12\r\n\x05value\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\x12\r\n\x05total\x18\x03 \x01(\x03\x12\x12\n\npercentage\x18\x04 \x01(\x01\x12\x0e\n\x06volume\x18\x05 \x01(\x03\x12\x14\n\x0ctotal_volume\x18\x06 \x01(\x03\x12\x19\n\x11volume_percentage\x18\x07 \x01(\x01\x32\xef\x01\n#TickTradeConditionStatisticsService\x12\xc7\x01\n\x1cTickTradeConditionStatistics\x12Q.systemathics.apis.services.tick_analytics.v1.TickTradeConditionStatisticsRequest\x1aR.systemathics.apis.services.tick_analytics.v1.TickTradeConditionStatisticsResponse0\x01\x62\x06proto3')



_TICKTRADECONDITIONSTATISTICSREQUEST = DESCRIPTOR.message_types_by_name['TickTradeConditionStatisticsRequest']
_TICKTRADECONDITIONSTATISTICSRESPONSE = DESCRIPTOR.message_types_by_name['TickTradeConditionStatisticsResponse']
TickTradeConditionStatisticsRequest = _reflection.GeneratedProtocolMessageType('TickTradeConditionStatisticsRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKTRADECONDITIONSTATISTICSREQUEST,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_trade_condition_statistics_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickTradeConditionStatisticsRequest)
  })
_sym_db.RegisterMessage(TickTradeConditionStatisticsRequest)

TickTradeConditionStatisticsResponse = _reflection.GeneratedProtocolMessageType('TickTradeConditionStatisticsResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKTRADECONDITIONSTATISTICSRESPONSE,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_trade_condition_statistics_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickTradeConditionStatisticsResponse)
  })
_sym_db.RegisterMessage(TickTradeConditionStatisticsResponse)

_TICKTRADECONDITIONSTATISTICSSERVICE = DESCRIPTOR.services_by_name['TickTradeConditionStatisticsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TICKTRADECONDITIONSTATISTICSREQUEST._serialized_start=236
  _TICKTRADECONDITIONSTATISTICSREQUEST._serialized_end=407
  _TICKTRADECONDITIONSTATISTICSRESPONSE._serialized_start=410
  _TICKTRADECONDITIONSTATISTICSRESPONSE._serialized_end=578
  _TICKTRADECONDITIONSTATISTICSSERVICE._serialized_start=581
  _TICKTRADECONDITIONSTATISTICSSERVICE._serialized_end=820
# @@protoc_insertion_point(module_scope)
