# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/corporate_actions/v1/dividends.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?systemathics/apis/services/corporate_actions/v1/dividends.proto\x12/systemathics.apis.services.corporate_actions.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\x98\x01\n\x10\x44ividendsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\"\\\n\x11\x44ividendsResponse\x12G\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x39.systemathics.apis.services.corporate_actions.v1.Dividend\"\x97\x01\n\x08\x44ividend\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12K\n\x04type\x18\x02 \x01(\x0e\x32=.systemathics.apis.services.corporate_actions.v1.DividendType\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x01\x12\r\n\x05score\x18\x04 \x01(\x01*^\n\x0c\x44ividendType\x12\x1d\n\x19\x44IVIDEND_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x44IVIDEND_TYPE_CASH\x10\x01\x12\x17\n\x13\x44IVIDEND_TYPE_STOCK\x10\x02\x32\xa7\x01\n\x10\x44ividendsService\x12\x92\x01\n\tDividends\x12\x41.systemathics.apis.services.corporate_actions.v1.DividendsRequest\x1a\x42.systemathics.apis.services.corporate_actions.v1.DividendsResponseb\x06proto3')

_DIVIDENDTYPE = DESCRIPTOR.enum_types_by_name['DividendType']
DividendType = enum_type_wrapper.EnumTypeWrapper(_DIVIDENDTYPE)
DIVIDEND_TYPE_UNSPECIFIED = 0
DIVIDEND_TYPE_CASH = 1
DIVIDEND_TYPE_STOCK = 2


_DIVIDENDSREQUEST = DESCRIPTOR.message_types_by_name['DividendsRequest']
_DIVIDENDSRESPONSE = DESCRIPTOR.message_types_by_name['DividendsResponse']
_DIVIDEND = DESCRIPTOR.message_types_by_name['Dividend']
DividendsRequest = _reflection.GeneratedProtocolMessageType('DividendsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DIVIDENDSREQUEST,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.dividends_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.DividendsRequest)
  })
_sym_db.RegisterMessage(DividendsRequest)

DividendsResponse = _reflection.GeneratedProtocolMessageType('DividendsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DIVIDENDSRESPONSE,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.dividends_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.DividendsResponse)
  })
_sym_db.RegisterMessage(DividendsResponse)

Dividend = _reflection.GeneratedProtocolMessageType('Dividend', (_message.Message,), {
  'DESCRIPTOR' : _DIVIDEND,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.dividends_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.Dividend)
  })
_sym_db.RegisterMessage(Dividend)

_DIVIDENDSSERVICE = DESCRIPTOR.services_by_name['DividendsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DIVIDENDTYPE._serialized_start=646
  _DIVIDENDTYPE._serialized_end=740
  _DIVIDENDSREQUEST._serialized_start=244
  _DIVIDENDSREQUEST._serialized_end=396
  _DIVIDENDSRESPONSE._serialized_start=398
  _DIVIDENDSRESPONSE._serialized_end=490
  _DIVIDEND._serialized_start=493
  _DIVIDEND._serialized_end=644
  _DIVIDENDSSERVICE._serialized_start=743
  _DIVIDENDSSERVICE._serialized_end=910
# @@protoc_insertion_point(module_scope)
