# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/indices/v1/components.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6systemathics/apis/services/indices/v1/components.proto\x12%systemathics.apis.services.indices.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\'\n\x11\x43omponentsRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\"Z\n\x12\x43omponentsResponse\x12\x44\n\ncomponents\x18\x01 \x03(\x0b\x32\x30.systemathics.apis.services.indices.v1.Component\"]\n\tComponent\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0e\n\x06weight\x18\x02 \x01(\x01\x32\x97\x01\n\x11\x43omponentsService\x12\x81\x01\n\nComponents\x12\x38.systemathics.apis.services.indices.v1.ComponentsRequest\x1a\x39.systemathics.apis.services.indices.v1.ComponentsResponseb\x06proto3')



_COMPONENTSREQUEST = DESCRIPTOR.message_types_by_name['ComponentsRequest']
_COMPONENTSRESPONSE = DESCRIPTOR.message_types_by_name['ComponentsResponse']
_COMPONENT = DESCRIPTOR.message_types_by_name['Component']
ComponentsRequest = _reflection.GeneratedProtocolMessageType('ComponentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTSREQUEST,
  '__module__' : 'systemathics.apis.services.indices.v1.components_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.indices.v1.ComponentsRequest)
  })
_sym_db.RegisterMessage(ComponentsRequest)

ComponentsResponse = _reflection.GeneratedProtocolMessageType('ComponentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTSRESPONSE,
  '__module__' : 'systemathics.apis.services.indices.v1.components_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.indices.v1.ComponentsResponse)
  })
_sym_db.RegisterMessage(ComponentsResponse)

Component = _reflection.GeneratedProtocolMessageType('Component', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENT,
  '__module__' : 'systemathics.apis.services.indices.v1.components_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.indices.v1.Component)
  })
_sym_db.RegisterMessage(Component)

_COMPONENTSSERVICE = DESCRIPTOR.services_by_name['ComponentsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPONENTSREQUEST._serialized_start=224
  _COMPONENTSREQUEST._serialized_end=263
  _COMPONENTSRESPONSE._serialized_start=265
  _COMPONENTSRESPONSE._serialized_end=355
  _COMPONENT._serialized_start=357
  _COMPONENT._serialized_end=450
  _COMPONENTSSERVICE._serialized_start=453
  _COMPONENTSSERVICE._serialized_end=604
# @@protoc_insertion_point(module_scope)
